<?php
/**
 * Plugin Name: WooCommerce Orders Progress bar - Pro
 * Plugin URI: http://www.appknitters.com/
 * Description: Displays visual progress bar on orders and single order pages in customer's My Account.
 * Version: 2.0.0
 * Author: 20script
 * Author URI: http://www.20script.ir/
 * Tested up to: 5.0.2
 *
 * Text Domain: woocommerce_order_progressbar
 * Domain Path: /lang/
 *
 */
if (!defined('ABSPATH')) {
    exit;
}
// Exit if accessed directly

include_once ABSPATH . 'wp-admin/includes/plugin.php';
if (!is_plugin_active('woocommerce/woocommerce.php')) {
    return;
}
if (!defined('WCOPB_VER')) {
    define('WCOPB_VER', 2.0);
}

if (!class_exists('ANWC_Order_Progress_Bar_Pro')) {

    class ANWC_Order_Progress_Bar_Pro
    {

        private $options, $style_options, $style;

        public function __construct()
        {
            // Get defualt options
            $defaults = $this->get_default_options();
            // loading saved options.
            $options = get_option('anwc_order_progressbar_pro');
            $this->options = wp_parse_args($options, $defaults);

            $this->generate_styles();
            // adding settings page menu.
            add_action('admin_menu', array($this, 'admin_menu'));

            // rendering settings feilds
            add_action('admin_init', array($this, 'admin_init'));
            // add css file for progress bar.
            add_action('wp_enqueue_scripts', array($this, 'scripts'));

            add_action('admin_enqueue_scripts', array($this, 'admin_scripts'));

            // Emails
            add_action('woocommerce_email_header', array($this, 'woocommerce_email_header'), 100, 2);

            //Adding markup in my-account
            add_action('woocommerce_my_account_my_orders_column_order-status', array($this, 'my_orders_column'));
            add_action('woocommerce_view_order', array($this, 'my_orders_column'));
            add_action('woocommerce_thankyou', array($this, 'my_orders_column'));
            add_action('manage_shop_order_posts_custom_column', array($this, 'shop_orders_column'), 10, 2);
        }

        public function scripts()
        {

            if (is_admin()) {

            } else {

                $selected_statuses = $this->options['wc_statuses'];
                $my_account_id = get_option('woocommerce_myaccount_page_id');
                $my_account = get_post_field('post_name', get_option('woocommerce_myaccount_page_id'));
                $checkout_page_id = wc_get_page_id('checkout');
                $checkout_page = get_post_field('post_name', $checkout_page_id);
                $is_orders_page = isset($this->options['is_orders_page']);
                $orders_page_slug = get_option('woocommerce_myaccount_orders_endpoint');
                $is_view_order_page = isset($this->options['is_view_order_page']);
                $view_order_page_slug = get_option('woocommerce_myaccount_view_order_endpoint');
                $is_order_received_page = isset($this->options['is_order_received_page']);
                $order_received_page_slug = get_option('woocommerce_checkout_order_received_endpoint');
                $is_order_tracking_page = isset($this->options['is_order_tracking_page']);

                $display_view_orders = false;
                if ($is_view_order_page && (strstr($_SERVER['REQUEST_URI'], $my_account . "/{$view_order_page_slug}/") || (isset($_REQUEST['page_id']) && $_REQUEST['page_id'] == $my_account_id && isset($_REQUEST['view-order'])))) {
                    $display_view_orders = true;

                } elseif ($is_order_received_page && (strstr($_SERVER['REQUEST_URI'], $checkout_page . "/{$order_received_page_slug}/") || (isset($_REQUEST['page_id']) && $_REQUEST['page_id'] == $checkout_page_id && isset($_REQUEST['order-received'])))) {
                    $display_view_orders = true;
                    $this->options['placement']['order'] = $this->options['placement']['order_received'];
                } elseif ($is_order_tracking_page && isset($_POST['track']) && $_POST['track'] == 'Track') {
                    $display_view_orders = true;
                    $this->options['placement']['order'] = $this->options['placement']['order_tracking'];
                }
                if ($is_orders_page && (strstr($_SERVER['REQUEST_URI'], $my_account . "/{$orders_page_slug}/") || (isset($_REQUEST['page_id']) && $_REQUEST['page_id'] == $my_account_id && isset($_REQUEST['orders'])))) {

                    // Script to trigger bar
                    wp_register_script('anwc_progress_bar', plugin_dir_url(__FILE__) . 'js/progress_bar_orders.js', array('jquery'));
                    $this->enqueue_commons();
                } elseif ($display_view_orders) {
                    // Theme

                    // Script to trigger bar
                    wp_register_script('anwc_progress_bar', plugin_dir_url(__FILE__) . 'js/progress_bar_view_order.js', array('jquery'));
                    $this->enqueue_commons();
                }
            }
        }

        public function admin_scripts($page)
        {
            if (isset($_GET['page']) && $_GET['page'] == 'anwc_order_progressbar_pro') {
                $wp_scripts = wp_scripts();
                wp_enqueue_style('anwc_progress_bar', plugin_dir_url(__FILE__) . 'css/progress-bar.css');
                wp_enqueue_style('spectrum', plugin_dir_url(__FILE__) . 'css/spectrum.css');
                wp_enqueue_style('jquery-ui', 'http://ajax.googleapis.com/ajax/libs/jqueryui/' . $wp_scripts->registered['jquery-ui-core']->ver . '/themes/smoothness/jquery-ui.css');
                wp_enqueue_style('anwc_progress_bar_options', plugin_dir_url(__FILE__) . 'css/admin_options.css');
                wp_enqueue_script('jquery-ui-core');
                wp_enqueue_script('jquery-ui-sortable');
                wp_enqueue_script('jquery-ui-tabs');
                wp_enqueue_script('spectrum', plugin_dir_url(__FILE__) . 'js/spectrum.js', array('jquery'));
                wp_enqueue_script('anwc_progress_bar_functions', plugin_dir_url(__FILE__) . 'js/functions.js', array('jquery'));
                wp_enqueue_script('anwc_progress_bar_options', plugin_dir_url(__FILE__) . 'js/admin_options.js', array('jquery', 'jquery-ui-sortable', 'jquery-ui-tabs'));
            }

            $selected_statuses = $this->options['wc_statuses'];

            $is_admin_orders_page = isset($this->options['is_admin_orders_page']);

            if ($is_admin_orders_page && $page == 'edit.php' && $_GET['post_type'] == 'shop_order') {
                // Script to trigger bar
                wp_register_script('anwc_progress_bar', plugin_dir_url(__FILE__) . 'js/admin-progress_bar_orders.js', array('jquery'));
                $this->enqueue_commons();
            }
        }

        // adds custom menu to admin menu. we are adding our Order deadlines menu here
        public function admin_menu()
        {

            add_submenu_page('woocommerce', 'Progress Bar', 'Orders Progress Bar', 'manage_woocommerce', 'anwc_order_progressbar_pro', array($this, 'admin_menu_settings'));
        }

        public function admin_menu_settings()
        {
            $wc_statuses = wc_get_order_statuses();
            // Set class property
            ?>
            <div class="wrap">
                <h1>Progress bar settings</h1>
                <form method="post" action="options.php">
                    <?php
// This prints out all hidden setting fields
            settings_fields('anwc_order_progressbar_pro_options');
            do_settings_sections('anwc_order_progressbar_pro');
            //do_settings_fields( 'anwc_order_progressbar_pro',false );
            submit_button();
            ?>
                </form>
            </div>
            <?php
}

        public function admin_init()
        {
            if (class_exists('ANWC_Order_Progress_Bar')) {
                deactivate_plugins('wc-orders-progress-bar/wc-order-progress-bar.php', true);
            }
            register_setting(
                'anwc_order_progressbar_pro_options', // Option group
                'anwc_order_progressbar_pro', // Option name
                array($this, 'sanitize') // Sanitize
            );
            add_settings_section(
                'anwc_order_progressbar_pro_basic', // ID
                'Basic', // Title
                array($this, 'print_basic_info'), // Callback
                'anwc_order_progressbar_pro' // Page
            );
            add_settings_field(
                'wc_statuses', // ID
                'Statuses to use', // Title
                array($this, 'wc_statuses_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_basic' // Section
            );

            add_settings_section(
                'anwc_order_progressbar_pro_pages', // ID
                'Pages', // Title
                array($this, 'print_pages_info'), // Callback
                'anwc_order_progressbar_pro' // Page
            );

            add_settings_field(
                'is_orders_page', // ID
                '', // Title
                array($this, 'wc_is_orders_page_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_pages' // Section
            );

            add_settings_field(
                'is_view_order_page', // ID
                '', // Title
                array($this, 'wc_is_view_order_page_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_pages' // Section
            );
            add_settings_field(
                'is_order_tracking_page', // ID
                '', // Title
                array($this, 'wc_is_order_tracking_page_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_pages' // Section
            );
            add_settings_field(
                'is_order_received_page', // ID
                '', // Title
                array($this, 'wc_is_order_reveived_page_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_pages' // Section
            );

            add_settings_field(
                'is_admin_orders_page', // ID
                '', // Title
                array($this, 'wc_is_admin_orders_page_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_pages' // Section
            );

            add_settings_field(
                'is_emails', // ID
                '', // Title
                array($this, 'wc_is_emails_page_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_pages' // Section
            );

            add_settings_section(
                'anwc_order_progressbar_pro_style', // ID
                'Style', // Title
                array($this, 'print_style_info'), // Callback
                'anwc_order_progressbar_pro' // Page
            );
            add_settings_field(
                'theme', // ID
                'Theme', // Title
                array($this, 'wc_theme_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_style' // Section
            );

            add_settings_field(
                'border', // ID
                'Border', // Title
                array($this, 'wc_border_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_style' // Section
            );

            add_settings_field(
                'is_shadow', // ID
                'Shadow', // Title
                array($this, 'wc_shadow_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_style' // Section
            );

            add_settings_field(
                'preview', // ID
                '', // Title
                array($this, 'wc_preview_callback'), // Callback
                'anwc_order_progressbar_pro', // Page
                'anwc_order_progressbar_pro_style' // Section
            );
        }

        public function wc_statuses_callback()
        {
            $statuses = wc_get_order_statuses();
            $selected_arr = $this->options['wc_statuses'];
            if (!is_array($selected_arr)) {
                $selected_arr = array();
            }
            ?>

            <div id="wc_statuses" style="display:none">

                <?php foreach ($selected_arr as $type => $type_arr): ?>
                    <?php foreach ($type_arr as $key => $title): ?>
                        <input type="hidden" value="<?php echo $title; ?>" name="anwc_order_progressbar_pro[wc_statuses][<?php echo $type; ?>][<?php echo $key; ?>]">
                    <?php endforeach;?>
                <?php endforeach;?>

            </div>
            <div id="statuses_selection_container">

                <div id="left">
                    <p>All Statuses</p>
                    <ul id="all_statuses" class="connected">
                        <?php foreach ($statuses as $slug => $title): ?>
                            <?php if (!in_array($title, $selected_arr['success']) && !in_array($title, $selected_arr['failed'])): ?>
                                <li data-id="<?php echo $slug; ?>" ><?php echo $title; ?></li>
                            <?php endif;?>
                        <?php endforeach;?>
                    </ul>
                </div>
                <div id="middle">
                    <p>Success</p>
                    <ul id="selected_statuses_success" class="connected successful">
                        <?php foreach ($selected_arr['success'] as $slug => $title): ?>

                            <li data-id="<?php echo $slug; ?>"><?php echo $title; ?></li>

                        <?php endforeach;?>
                    </ul>
                </div>
                <div id="right">
                    <p>Failed</p>
                    <ul id="selected_statuses_failed" class="connected failed">
                        <?php foreach ($selected_arr['failed'] as $slug => $title): ?>

                            <li data-id="<?php echo $slug; ?>"><?php echo $title; ?></li>

                        <?php endforeach;?>
                    </ul>
                </div>
            </div>
            <span> Please drop status of your choice from left panel into right panel. you can re-arrange status position on progress bar by dragging up and down in right(Selected) panel.</span>

            <?php
}
        /**
         * @todo : Add placement options for each page. e.g. show below/above order on "Customer orders page" etc.

        @todo: Allow user to enter custom css class/ID to show progress bar, below or above it.
        @todo: Allow some statuse to be show on both SUCCESS and FAILED progress bas.
        @todo: add new animations.
         */
        public function wc_is_orders_page_callback()
        {
            $checked = isset($this->options['is_orders_page']) ? $this->options['is_orders_page'] : '';

            $places = array('below' => 'Below order details', 'above' => 'Above order details');
            $selected = isset($this->options['placement']['orders']) ? $this->options['placement']['orders'] : 'below';
            ?>

            <label for="is_orders_page" ><input class="is_page" type="checkbox" id="is_orders_page" name="anwc_order_progressbar_pro[is_orders_page]" <?php checked($checked, 'on');?>/> Orders Page</label>
            <div class="placements">
            <select id="placement_orders" name="anwc_order_progressbar_pro[placement][orders]"  >
                <?php foreach ($places as $key => $title): ?>
                    <option value="<?php echo $key; ?>" <?php selected($selected, $key);?>><?php echo $title ?></option>
                <?php endforeach;?>
            </select>
            </div>
            <?php
}

        public function wc_is_view_order_page_callback()
        {
            $checked = isset($this->options['is_view_order_page']) ? $this->options['is_view_order_page'] : '';
            $places = array('entry-header||above' => 'Above title', 'entry-header||below' => 'Below title', 'woocommerce-order-details||above' => 'Above order details', 'woocommerce-order-details||below' => 'Below order details', 'woocommerce-customer-details||above' => 'Above customer details', 'woocommerce-customer-details||below' => 'Below customer details');
            $selected = isset($this->options['placement']['order']) ? $this->options['placement']['order'] : 'entry-header||below';
            ?>
            <label for="is_view_order_page" ><input class="is_page" type="checkbox" id="is_view_order_page" name="anwc_order_progressbar_pro[is_view_order_page]" <?php checked($checked, 'on');?>/> View order page</label>
            <div class="placements">
            <select id="placement_order" name="anwc_order_progressbar_pro[placement][order]"  >

                <?php foreach ($places as $key => $title): ?>
                    <option value="<?php echo $key; ?>" <?php selected($selected, $key);?>><?php echo $title ?></option>
                <?php endforeach;?>
            </select>
            </div>
            <?php
}

        public function wc_is_order_reveived_page_callback()
        {
            $checked = isset($this->options['is_order_received_page']) ? $this->options['is_order_received_page'] : '';
            $places = array('entry-header||above' => 'Above title', 'entry-header||below' => 'Below title', 'woocommerce-order-details||above' => 'Above order details', 'woocommerce-order-details||below' => 'Below order details', 'woocommerce-customer-details||above' => 'Above customer details', 'woocommerce-customer-details||below' => 'Below customer details');
            $selected = isset($this->options['placement']['order_received']) ? $this->options['placement']['order_received'] : 'entry-header||below';
            ?>
            <label for="is_order_received_page" ><input class="is_page" type="checkbox" id="is_order_received_page" name="anwc_order_progressbar_pro[is_order_received_page]" <?php checked($checked, 'on');?>/> Order received page</label>
            <div class="placements">
            <select id="placement_order_received" name="anwc_order_progressbar_pro[placement][order_received]"  >
                <?php foreach ($places as $key => $title): ?>
                    <option value="<?php echo $key; ?>" <?php selected($selected, $key);?>><?php echo $title ?></option>
                <?php endforeach;?>
            </select>
            </div>
            <?php
}

        public function wc_is_order_tracking_page_callback()
        {
            $checked = isset($this->options['is_order_tracking_page']) ? $this->options['is_order_tracking_page'] : '';
            $places = array('entry-header||above' => 'Above title', 'entry-header||below' => 'Below title', 'woocommerce-order-details||above' => 'Above order details', 'woocommerce-order-details||below' => 'Below order details', 'woocommerce-customer-details||above' => 'Above customer details', 'woocommerce-customer-details||below' => 'Below customer details');
            $selected = isset($this->options['placement']['order_tracking']) ? $this->options['placement']['order_tracking'] : 'entry-header||below';
            ?>
            <label for="is_order_tracking_page" ><input class="is_page" type="checkbox" id="is_order_tracking_page" name="anwc_order_progressbar_pro[is_order_tracking_page]" <?php checked($checked, 'on');?>/> Order tracking page</label>
            <div class="placements">
            <select id="placement_order_traking" name="anwc_order_progressbar_pro[placement][order_tracking]"  >
                <?php foreach ($places as $key => $title): ?>
                    <option value="<?php echo $key; ?>" <?php selected($selected, $key);?>><?php echo $title ?></option>
                <?php endforeach;?>
            </select>
            </div>
            <?php
}

        public function wc_is_admin_orders_page_callback()
        {
            $checked = isset($this->options['is_admin_orders_page']) ? $this->options['is_admin_orders_page'] : '';
            $places = array('below' => 'Below order details', 'above' => 'Above order details');
            $selected = isset($this->options['placement']['admin_orders']) ? $this->options['placement']['admin_orders'] : 'below';

            ?>
            <label for="is_admin_orders_page" ><input class="is_page" type="checkbox" id="is_admin_orders_page" name="anwc_order_progressbar_pro[is_admin_orders_page]" <?php checked($checked, 'on');?>/> Admin orders listing page</label>
            <div class="placements">
            <select id="placement_admin_orders" name="anwc_order_progressbar_pro[placement][admin_orders]"  >

                <?php foreach ($places as $key => $title): ?>
                    <option value="<?php echo $key; ?>" <?php selected($selected, $key);?>><?php echo $title ?></option>
                <?php endforeach;?>
            </select>
            </div>
            <?php
}

        public function wc_is_emails_page_callback()
        {
            $checked = isset($this->options['is_emails']) ? $this->options['is_emails'] : '';
            ?>
            <label for="is_emails" ><input type="checkbox" id="is_emails" name="anwc_order_progressbar_pro[is_emails]" <?php checked($checked, 'on');?>/> Order Emails</label>

            <?php
}

        public function wc_theme_callback()
        {
            //print_r($this->options['color']);
            $types = ['success', 'failed'];
            foreach ($types as $type) {
                $selected = isset($this->options['theme'][$type]) ? $this->options['theme'][$type] : '';
                $color = isset($this->options['color'][$type]) ? $this->options['color'][$type] : '';
                $bgcolor = isset($this->options['bgcolor'][$type]) ? $this->options['bgcolor'][$type] : 'lightgray';

                $themes = ['stripes' => 'Stripes', 'stripes-lg' => 'Stripes Large', 'glow' => 'Glow', 'shine' => 'Shine', 'rainbow' => 'Rainbow', 'blinds' => 'Blinds'];

                $themes = apply_filters('an_orders_progress_bar_themes', $themes);
                ?>
        <div style="width:49%;float:left">
            <h4><?php echo ucwords($type); ?></h4>
            <select id="theme_<?php echo $type; ?>" name="anwc_order_progressbar_pro[theme][<?php echo $type; ?>]"  >
                <option value="" <?php selected($selected, '');?>>Default</option>
                <?php foreach ($themes as $key => $title): ?>
                    <option value="<?php echo $key; ?>" <?php selected($selected, $key);?>><?php echo $title ?></option>
                <?php endforeach;?>
            </select>
            <p>
                <label for="color_<?php echo $type; ?>">
                    <input type="text" id="color_<?php echo $type; ?>" name="anwc_order_progressbar_pro[color][<?php echo $type; ?>]" value="<?php echo $color; ?>" class='colors_picker'/>
                    <span>Progress color</span>
                </label>
            </p>
            <p>
                <label for="bgcolor_<?php echo $type; ?>">
                    <input type="text" id="bgcolor_<?php echo $type; ?>" name="anwc_order_progressbar_pro[bgcolor][<?php echo $type; ?>]" value="<?php echo $bgcolor; ?>" class='colors_picker' />
                    <span>Background color</span>
                </label>
            </p>

        </div>
            <?php
}
        }

        public function wc_border_callback()
        {
            $width = isset($this->options['border']['width']) ? $this->options['border']['width'] : '0';
            $radius = isset($this->options['border']['radius']) ? $this->options['border']['radius'] : '20';
            $color = isset($this->options['border']['color']) ? $this->options['border']['color'] : 'white';
            $selected = isset($this->options['border']['style']) ? $this->options['border']['style'] : 'solid';
            ?>

            <label for="border_width">
            <p>Width</p>
            <input type="number" id="border_width" name="anwc_order_progressbar_pro[border][width]" value="<?php echo $width; ?>" />px
            </label>
            <br/><br/>
            <label for="border_style">
            <p>Style</p>
            <select id="border_style" name="anwc_order_progressbar_pro[border][style]"  >
                <option value="solid" <?php selected($selected, 'solid');?>>Solid</option>
                <option value="dotted" <?php selected($selected, 'dotted');?>>Dotted</option>
                <option value="dashed" <?php selected($selected, 'dashed');?>>Dashed</option>
                <option value="double" <?php selected($selected, 'double');?>>Double</option>
                <option value="groove" <?php selected($selected, 'groove');?>>Groove</option>
                <option value="ridge" <?php selected($selected, 'ridge');?>>Ridge</option>
                <option value="inset" <?php selected($selected, 'inset');?>>Inset</option>
                <option value="outset" <?php selected($selected, 'outset');?>>Outset</option>
            </select>
            </label>
            <br/><br/>
            <label for="border_color">
            <p>Color</p>
            <input type="text" id="border_color" name="anwc_order_progressbar_pro[border][color]" value="<?php echo $color; ?>" class='colors_picker' />
            </label>
            <br/><br/>
            <label for="border_radius">
            <p>Radius (Between 0px and 15px)</p>
            <input title="Border Radius" type="number" id="border_radius" name="anwc_order_progressbar_pro[border][radius]" value="<?php echo $radius; ?>" min="0" max="15" />px
            </label>
            <?php
}
        public function wc_shadow_callback()
        {
            $checked = isset($this->options['is_shadow']) ? $this->options['is_shadow'] : '';
            ?>
            <label for="is_shadow" ><input type="checkbox" id="is_shadow" name="anwc_order_progressbar_pro[is_shadow]" <?php checked($checked, 'on');?>/> Drop shadow</label>

            <?php
}

        public function wc_preview_callback()
        {
            ?>
            <div id="anwcpb_preview">
                <a id="hide-preview" href="javascript:void(0);"> &#8853; Toggle Preview </a>
                <div class="success"></div>
                <div class="failed"></div>
            </div>
            <?php
}

        public function sanitize($input)
        {
            $new_input = array();
            // if (isset($input['wc_statuses']))
            //$input['wc_statuses'] = serialize($input['wc_statuses']);
            return $input;
        }

        public function print_basic_info()
        {
            print 'Please select woocommerce statuses to display in progress bar.';
        }

        public function print_pages_info()
        {
            print 'Please select pages on which you want to display progress bar.';
        }

        public function print_style_info()
        {
            print 'Please select style related options for your bar.';
        }

        public function woocommerce_email_header($heading, $email = false)
        {

            $is_emails = isset($this->options['is_emails']);
            $order = $email->object;

            if ($is_emails && is_object($order) && is_a($order, 'WC_Order')) {
                $sel_stages = $this->options['wc_statuses'];
                $wc_statuses = wc_get_order_statuses();

                $stage_slug = $order->get_status();
                $stage = $wc_statuses['wc-' . $stage_slug];
                foreach ($sel_stages as $type => $stages) {
                    if (array_key_exists($stage, $stages)) {
                        $style_options['theme'] = isset($this->options['theme'][$type]) ? $this->options['theme'][$type] : '';
                        $style_options['color'] = isset($this->options['color'][$type]) ? $this->options['color'][$type] : '';
                        $style_options['bgcolor'] = isset($this->options['bgcolor'][$type]) ? $this->options['bgcolor'][$type] : 'lightgray';
                        $style_options['border'] = isset($this->options['border']) ? $this->options['border'] : '';
                        $border_style = array('corners' => 0, 'rounded' => 10, 'circle' => 20);

                        $style = array();
                        $style['meter'] = "-moz-border-radius: {$border_style[$this->options['border']]}px;-webkit-border-radius: {$border_style[$this->options['border']]}px;border-radius: {$border_style[$this->options['border']]}px;height: 30px;position: relative;background:" . $style_options['bgcolor'] . ";box-shadow: inset 0 -1px 1px rgba(255,255,255,0.3);";
                        $style['meter:after'] = "border-color:" . $this->darken_color($style_options['color']) . " !important;-moz-border-radius: {$border_style[$this->options['border']]}px;-webkit-border-radius: {$border_style[$this->options['border']]}px;border-radius: {$border_style[$this->options['border']]}px; }";
                        $style['meter span'] = "border-radius: {$border_style[$this->options['border']]}px;background:" . $style_options['color'] . ";display: block;height: 100%;position: relative;overflow: hidden;";
                        $style['meter span:after'] = "background:" . $this->darken_color($style_options['color']) . " !important;-moz-border-radius: {$border_style[$this->options['border']]}px;-webkit-border-radius: {$border_style[$this->options['border']]}px;border-radius: {$border_style[$this->options['border']]}px;float:right;display:block;height:30px;width:30px;overflow:hidden;";
                        /*
                        if($style_options['theme']=='stripes'){
                        $style['meter']='';
                        $style['meter:after']='';
                        $style['meter span'] = '';
                        $style['meter span:after'] ='';
                        }elseif($style_options['theme']=='glow'){
                        $style['meter']='';
                        $style['meter:after']='';
                        $style['meter span'] = '';
                        $style['meter span:after'] ='';
                        }elseif($style_options['theme']=='shine'){
                        $style['meter']='';
                        $style['meter:after']='';
                        $style['meter span'] = '';
                        $style['meter span:after'] ='';
                        }else{
                        $style['meter']='';
                        $style['meter:after']='';
                        $style['meter span'] = '';
                        $style['meter span:after'] ='';
                        }
                         */

                        $stage_scores = array();
                        $stage_name_html = '';
                        $unit = 100 / (count($stages) - 1);
                        $stage_unit = 100 / count($stages);
                        $i = 0;
                        foreach ($stages as $slug => $_stage) {
                            $stage_scores[$_stage] = ($unit * $i) ? $unit * $i : 7;
                            $display = 'inline-block';
                            if ($i == (count($stages) - 1)) {
                                $display = 'inline';
                            }
                            $last = $i == (count($stages) - 1) ? 'text-align:right;' : 'text-align:left;';
                            $current = $stage == $_stage ? 'font-weight:900;text-decoration:underline;' : 'font-weight:normal;';
                            $stage_name_html .= '<span style="' . $current . $last . ' width:' . ($unit - 5) . '%;font-size:10px;white-space:nowrap;display:' . $display . ';">' . $_stage . '</span>';
                            $i++;
                        }

                        $order_number = trim(str_replace('#', '', $order->get_order_number()));
                        $html = '<div id="progress_bar" style="width:80%;margin:0 auto;">'
                        . '<div class="meter" style="' . $style['meter'] . '">'
                        . '<div style="width: ' . ($stage_scores[$stage] == 100 ? '100' : $stage_scores[$stage]) . '%;' . $style['meter span'] . '">'
                        . '<span class="after" style="' . $style['meter span:after'] . '"></span>'
                        . '</div>'
                        //. '<span class="meter_after" style="display:block;height:26px;width:26px;background:transparent;-moz-border-radius:20px;-webkit-border-radius:20px;border-radius:20px;border:2px solid darkgreen;overflow:hidden;"></span>'
                         . '</div>'
                            . '<div class="stage_names" style="width:100%;">' . $stage_name_html . '</div>'
                            . '</div><br><br>';
                        echo $html;
                    }
                }
            }
        }

        public function my_orders_column($order)
        {
            if (is_object($order)) {
                $order_number = $order->get_id();
                $order_status = $order->get_status();
                echo wc_get_order_status_name($order_status);
            } else {
                $order_number = $order;
                $order = wc_get_order($order);
                $order_status = $order->get_status();
            }
            ?>

            <input type="hidden" id="opb_order_number" value="<?php echo $order_number; ?>" />
            <input type="hidden" id="opb_order_status" value="wc-<?php echo $order_status; ?>" />

            <?php
}

        public function shop_orders_column($column, $order)
        {
            if ($column == 'order_status') {
                if (is_object($order)) {
                    $order_number = $order->get_id();
                    $order_status = $order->get_status();
                    echo wc_get_order_status_name($order_status);
                } else {
                    $order_number = $order;
                    $order = wc_get_order($order);
                    $order_status = $order->get_status();
                }
                ?>

                <input type="hidden" id="opb_order_number" value="<?php echo $order_number; ?>" />
                <input type="hidden" id="opb_order_status" value="wc-<?php echo $order_status; ?>" />

                <?php
}
        }

        private function darken_color($rgb, $darker = 2)
        {

            $hash = (strpos($rgb, '#') !== false) ? '#' : '';
            $rgb = (strlen($rgb) == 7) ? str_replace('#', '', $rgb) : ((strlen($rgb) == 6) ? $rgb : false);
            if (strlen($rgb) != 6) {
                return $hash . '000000';
            }

            $darker = ($darker > 1) ? $darker : 1;

            list($R16, $G16, $B16) = str_split($rgb, 2);

            $R = sprintf("%02X", floor(hexdec($R16) / $darker));
            $G = sprintf("%02X", floor(hexdec($G16) / $darker));
            $B = sprintf("%02X", floor(hexdec($B16) / $darker));

            return $hash . $R . $G . $B;
        }

        private function get_default_options()
        {

            $defaults['wc_statuses'] = array(
                'success' => [
                    'wc-pending' => 'Pending payment',
                    'wc-on-hold' => 'On hold',
                    'wc-processing' => 'Processing',
                    'wc-completed' => 'Completed',
                ],
                'failed' => [
                    'wc-cancelled' => 'Cancelled',
                    'wc-refunded' => 'Refunded',
                    'wc-failed' => 'Failed',
                ],
            );
            $defaults['theme']['success'] = 'stripes';
            $defaults['color']['success'] = '#4db91b';
            $defaults['bgcolor']['success'] = 'lightgray';

            $defaults['theme']['failed'] = 'glow';
            $defaults['color']['failed'] = 'red';
            $defaults['bgcolor']['failed'] = 'lightgray';

            $defaults['border']['radius'] = 15;
            $defaults['border']['style'] = 'solid';
            $defaults['border']['width'] = 0;
            $defaults['border']['color'] = 'white';

            return $defaults;
        }

        private function generate_styles()
        {
            $types = ['success', 'failed'];
            $this->style = "";
            foreach ($types as $type) {
                $this->style_options['theme'][$type] = isset($this->options['theme'][$type]) ? $this->options['theme'][$type] : '';
                $this->style_options['color'][$type] = isset($this->options['color'][$type]) ? $this->options['color'][$type] : '';
                $this->style_options['bgcolor'][$type] = isset($this->options['bgcolor'][$type]) ? $this->options['bgcolor'][$type] : '';
                $this->style_options['border'][$type] = isset($this->options['border']['radius']) ? $this->options['border']['radius'] : '';
                $shadow = isset($this->options['is_shadow']) && $this->options['is_shadow'] == 'on' ? "box-shadow:0 3px 5px;" : "";
                //$border_style = array('corners' => 0, 'rounded' => 10, 'circle' => 20);
                $this->style .= ".{$type} .meter:after {border-color:" . $this->darken_color($this->style_options['color'][$type]) . " !important;-moz-border-radius: {$this->options['border']['radius']}px;-webkit-border-radius: {$this->options['border']['radius']}px;border-radius: {$this->options['border']['radius']}px; } .{$type} .meter span:after{background:" . $this->darken_color($this->style_options['color'][$type]) . " !important;-moz-border-radius: {$this->options['border']['radius']}px;-webkit-border-radius: {$this->options['border']['radius']}px;border-radius: {$this->options['border']['radius']}px; }.meter {-moz-border-radius: {$this->options['border']['radius']}px;-webkit-border-radius: {$this->options['border']['radius']}px;border-radius: {$this->options['border']['radius']}px; border:{$this->options['border']['width']}px {$this->options['border']['style']} {$this->options['border']['color']};{$shadow} } .{$type} .meter span{-moz-border-radius: {$this->options['border']['radius']}px;-webkit-border-radius: {$this->options['border']['radius']}px;border-radius: {$this->options['border']['radius']}px; }";
            }
        }

        private function enqueue_commons()
        {
            $selected_statuses = $this->options['wc_statuses'];

            //Progress bar theme
            wp_enqueue_style('anwc_progress_bar', plugin_dir_url(__FILE__) . 'css/progress-bar.css');
            wp_add_inline_style('anwc_progress_bar', $this->style);
            // Script to trigger bar
            wp_enqueue_script('anwc_progress_bar_functions', plugin_dir_url(__FILE__) . 'js/functions.js', array('jquery'));
            wp_localize_script('anwc_progress_bar', 'anwc_stages', $selected_statuses);
            wp_localize_script('anwc_progress_bar', 'anwc_style', $this->style_options);
            wp_localize_script('anwc_progress_bar', 'anwc_placements', $this->options['placement']);
            wp_enqueue_script('anwc_progress_bar');
        }

    }

    new ANWC_Order_Progress_Bar_Pro();
}